# DomainsApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**createDomain**](DomainsApi.md#createDomain) | **POST** /account/{accountId}/domains | 
[**deleteDomain**](DomainsApi.md#deleteDomain) | **DELETE** /account/{accountId}/domains/{domainName} | 
[**getDomainDetails**](DomainsApi.md#getDomainDetails) | **GET** /account/{accountId}/domains/{domainName} | 
[**getDomainsReport**](DomainsApi.md#getDomainsReport) | **GET** /account/{accountId}/domains | 
[**updateDomain**](DomainsApi.md#updateDomain) | **PUT** /account/{accountId}/domains/{domainName} | 

<a name="createDomain"></a>
# **createDomain**
> InlineResponse20059 createDomain(accountId, body, cookie)



Create a new domain in your account. Note: the domain MUST be either a subdomain or have client-managed DNS.  For HIPAA accounts, all new domains will be locked down for HIPAA compliance unless the account is configured as “HIPAA Flexible.” In that case, all new domains cannot be created via the API.  Your API Interface looks to see how many domains were added to your account in the past 24 hours. If this number is equal or greater than your API create limit, then your API will reject additional domain creation requests until that situation changes. See your API Interface configuration page for your domain creation limit. {{ACL: Account: Domains - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.DomainsApi;


DomainsApi apiInstance = new DomainsApi();
String accountId = "accountId_example"; // String | 
AccountIdDomainsBody body = new AccountIdDomainsBody(); // AccountIdDomainsBody | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse20059 result = apiInstance.createDomain(accountId, body, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling DomainsApi#createDomain");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **body** | [**AccountIdDomainsBody**](AccountIdDomainsBody.md)|  | [optional]
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse20059**](InlineResponse20059.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="deleteDomain"></a>
# **deleteDomain**
> InlineResponse2003 deleteDomain(accountId, domainName, cookie)



Remove a domain from your account. If the domain is currently in use (e.g. has users, web sites, has premium filtering or archival, has managed DNS, etc.), then it cannot be deleted. Note: the domain MUST be either a subdomain or have client-managed DNS. {{ACL: Account: Domains - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.DomainsApi;


DomainsApi apiInstance = new DomainsApi();
String accountId = "accountId_example"; // String | 
String domainName = "domainName_example"; // String | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse2003 result = apiInstance.deleteDomain(accountId, domainName, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling DomainsApi#deleteDomain");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **domainName** | **String**|  |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDomainDetails"></a>
# **getDomainDetails**
> InlineResponse20060 getDomainDetails(accountId, domainName, cookie)



Get information about a specific domain. This is the same as the “Get Domain Report,” except that it returns data for 1 specific domain. {{ACL: Account: Domains - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.DomainsApi;


DomainsApi apiInstance = new DomainsApi();
String accountId = "accountId_example"; // String | 
String domainName = "domainName_example"; // String | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse20060 result = apiInstance.getDomainDetails(accountId, domainName, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling DomainsApi#getDomainDetails");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **domainName** | **String**|  |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse20060**](InlineResponse20060.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDomainsReport"></a>
# **getDomainsReport**
> InlineResponse20058 getDomainsReport(accountId, cookie)



Get information about your domains. {{ACL: Account: Domains - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.DomainsApi;


DomainsApi apiInstance = new DomainsApi();
String accountId = "accountId_example"; // String | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse20058 result = apiInstance.getDomainsReport(accountId, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling DomainsApi#getDomainsReport");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse20058**](InlineResponse20058.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updateDomain"></a>
# **updateDomain**
> InlineResponse201 updateDomain(accountId, domainName, body, cookie)



Change selected domain settings.  You can change one or multiple settings via one call. Settings that are omitted will not be altered. {{ACL: Account: Domains - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.DomainsApi;


DomainsApi apiInstance = new DomainsApi();
String accountId = "accountId_example"; // String | 
String domainName = "domainName_example"; // String | 
DomainsDomainNameBody body = new DomainsDomainNameBody(); // DomainsDomainNameBody | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse201 result = apiInstance.updateDomain(accountId, domainName, body, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling DomainsApi#updateDomain");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **domainName** | **String**|  |
 **body** | [**DomainsDomainNameBody**](DomainsDomainNameBody.md)|  | [optional]
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

