# EmailAliasesApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**createAlias**](EmailAliasesApi.md#createAlias) | **POST** /account/{accountId}/aliases | 
[**deleteAlias**](EmailAliasesApi.md#deleteAlias) | **DELETE** /account/{accountId}/aliases/{aliasAddress} | 
[**getAliasDetails**](EmailAliasesApi.md#getAliasDetails) | **GET** /account/{accountId}/aliases/{aliasAddress} | 
[**getAliasesReport**](EmailAliasesApi.md#getAliasesReport) | **GET** /account/{accountId}/aliases | 
[**updateAlias**](EmailAliasesApi.md#updateAlias) | **PUT** /account/{accountId}/aliases/{aliasAddress} | 

<a name="createAlias"></a>
# **createAlias**
> InlineResponse20064 createAlias(accountId, body, cookie)



Create new alias(es) in your account.  Your API Interface looks to see how many aliases were added to your account in the past 24 hours. If this number is equal or greater than your API create limit, then your API will reject additional alias creation requests until that situation changes. See your API Interface configuration page for your alias creation limit.  Note also that accounts are limited in the maximum number of email aliases permitted per domain. By default, this is 100 + 10 aliases per user in the domain. So, for a domain with 20 users, this would be 100 + 10x20 &#x3D; 300 aliases. {{ACL: Account: Email Aliases - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailAliasesApi;


EmailAliasesApi apiInstance = new EmailAliasesApi();
String accountId = "accountId_example"; // String | 
AccountIdAliasesBody body = new AccountIdAliasesBody(); // AccountIdAliasesBody | The Request body contains the following settings for new email aliases. While you can add multiple aliases at once, you should not have duplicates in your list.
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse20064 result = apiInstance.createAlias(accountId, body, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailAliasesApi#createAlias");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **body** | [**AccountIdAliasesBody**](AccountIdAliasesBody.md)| The Request body contains the following settings for new email aliases. While you can add multiple aliases at once, you should not have duplicates in your list. | [optional]
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse20064**](InlineResponse20064.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="deleteAlias"></a>
# **deleteAlias**
> InlineResponse201 deleteAlias(accountId, aliasAddress, cookie)



Remove an alias with the specified alias email address from your account. {{ACL: Account: Email Aliases - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailAliasesApi;


EmailAliasesApi apiInstance = new EmailAliasesApi();
String accountId = "accountId_example"; // String | 
String aliasAddress = "aliasAddress_example"; // String | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse201 result = apiInstance.deleteAlias(accountId, aliasAddress, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailAliasesApi#deleteAlias");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **aliasAddress** | **String**|  |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getAliasDetails"></a>
# **getAliasDetails**
> InlineResponse20065 getAliasDetails(accountId, aliasAddress, cookie)



Get information about a specific email alias. {{ACL: Account: Email Aliases - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailAliasesApi;


EmailAliasesApi apiInstance = new EmailAliasesApi();
String accountId = "accountId_example"; // String | 
String aliasAddress = "aliasAddress_example"; // String | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse20065 result = apiInstance.getAliasDetails(accountId, aliasAddress, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailAliasesApi#getAliasDetails");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **aliasAddress** | **String**|  |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse20065**](InlineResponse20065.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getAliasesReport"></a>
# **getAliasesReport**
> InlineResponse20063 getAliasesReport(accountId, cookie)



Get information about your email aliases including regular aliases user forwards, domain catchalls, and WebAide Group distribution lists. {{ACL: Account: Email Aliases - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailAliasesApi;


EmailAliasesApi apiInstance = new EmailAliasesApi();
String accountId = "accountId_example"; // String | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse20063 result = apiInstance.getAliasesReport(accountId, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailAliasesApi#getAliasesReport");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse20063**](InlineResponse20063.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="updateAlias"></a>
# **updateAlias**
> InlineResponse201 updateAlias(accountId, aliasAddress, body, cookie)



Modify an existing alias in your account.  This function allows you to modify regular email aliases in your account. It does not permit modification of “catch all” aliases, “user forwards,” and system aliases such as WebAide Group Distribution Lists. You can use this function to enable and disable aliases; however, you must use a separate API call to actually delete them. {{ACL: Account: Email Aliases - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailAliasesApi;


EmailAliasesApi apiInstance = new EmailAliasesApi();
String accountId = "accountId_example"; // String | 
String aliasAddress = "aliasAddress_example"; // String | 
AliasesAliasAddressBody body = new AliasesAliasAddressBody(); // AliasesAliasAddressBody | The Request body contains the following settings for updating an email alias.
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse201 result = apiInstance.updateAlias(accountId, aliasAddress, body, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailAliasesApi#updateAlias");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **aliasAddress** | **String**|  |
 **body** | [**AliasesAliasAddressBody**](AliasesAliasAddressBody.md)| The Request body contains the following settings for updating an email alias. | [optional]
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

