# EmailApi

All URIs are relative to *https://rest.luxsci.com/perl/api/v2*, unless a hostname is provided ([see README](../README.md#documentation-for-api-endpoints))

Method | HTTP request | Description
------------- | ------------- | -------------
[**createCustomBounceDomain**](EmailApi.md#createCustomBounceDomain) | **POST** /account/{accountId}/bounce_domain | 
[**createDkim**](EmailApi.md#createDkim) | **POST** /account/{accountId}/dkim | 
[**deleteDkim**](EmailApi.md#deleteDkim) | **DELETE** /account/{accountId}/dkim/{domainName} | 
[**deleteEmailAutoResponder**](EmailApi.md#deleteEmailAutoResponder) | **DELETE** /user/{username}/email/ar/{id} | 
[**getDkimDetails**](EmailApi.md#getDkimDetails) | **GET** /account/{accountId}/dkim/{domainName} | 
[**getDkimReport**](EmailApi.md#getDkimReport) | **GET** /account/{accountId}/dkim | 
[**getEmailAutoResponders**](EmailApi.md#getEmailAutoResponders) | **GET** /user/{username}/email/ar | 
[**newEmailAutoResponder**](EmailApi.md#newEmailAutoResponder) | **POST** /user/{username}/email/ar | 
[**retrieveSecureLineRecipientListEncryptionData**](EmailApi.md#retrieveSecureLineRecipientListEncryptionData) | **POST** /user/{username}/email/compose/secureline/recipients | 
[**updateEmailForwarding**](EmailApi.md#updateEmailForwarding) | **PUT** /user/{username}/email/forwarding | 

<a name="createCustomBounceDomain"></a>
# **createCustomBounceDomain**
> createCustomBounceDomain(accountId, body, cookie)



Add a new Custom Bounce Domain to the account.  The bounce domain must be a subdomain of the from domain in question, have DKIM configured already, and the DNS must already be a CNAME to any of the target domains listed in the Custom Bounce Domains user interface area. {{ACL: Account: Domains - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailApi;


EmailApi apiInstance = new EmailApi();
String accountId = "accountId_example"; // String | 
AccountIdBounceDomainBody body = new AccountIdBounceDomainBody(); // AccountIdBounceDomainBody | 
String cookie = null; // String (optional. can leave as null) | 
try {
    apiInstance.createCustomBounceDomain(accountId, body, cookie);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailApi#createCustomBounceDomain");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **body** | [**AccountIdBounceDomainBody**](AccountIdBounceDomainBody.md)|  | [optional]
 **cookie** | **String**|  | [optional]

### Return type

null (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined

<a name="createDkim"></a>
# **createDkim**
> createDkim(accountId, body, cookie)



Create a new DKIM configuration in your account. {{ACL: Account: Domains - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailApi;


EmailApi apiInstance = new EmailApi();
String accountId = "accountId_example"; // String | 
AccountIdDkimBody body = new AccountIdDkimBody(); // AccountIdDkimBody | 
String cookie = null; // String (optional. can leave as null) | 
try {
    apiInstance.createDkim(accountId, body, cookie);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailApi#createDkim");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **body** | [**AccountIdDkimBody**](AccountIdDkimBody.md)|  | [optional]
 **cookie** | **String**|  | [optional]

### Return type

null (empty response body)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: Not defined

<a name="deleteDkim"></a>
# **deleteDkim**
> InlineResponse201 deleteDkim(accountId, domainName, cookie)



Remove a DKIM definition from your account. {{ACL: Account: Domains - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailApi;


EmailApi apiInstance = new EmailApi();
String accountId = "accountId_example"; // String | 
String domainName = "domainName_example"; // String | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse201 result = apiInstance.deleteDkim(accountId, domainName, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailApi#deleteDkim");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **domainName** | **String**|  |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="deleteEmailAutoResponder"></a>
# **deleteEmailAutoResponder**
> InlineResponse201 deleteEmailAutoResponder(username, id, cookie)



Delete an email auto-responder number &#x60;id&#x60; that belongs to the user. {{ACL:User Email - Auto-Responders}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailApi;


EmailApi apiInstance = new EmailApi();
String username = "username_example"; // String | 
String id = "id_example"; // String | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse201 result = apiInstance.deleteEmailAutoResponder(username, id, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailApi#deleteEmailAutoResponder");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |
 **id** | **String**|  |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDkimDetails"></a>
# **getDkimDetails**
> InlineResponse20062 getDkimDetails(accountId, domainName, cookie)



Get information about a specific DKIM configuration. This is the same as the “Get DKIM Report,” except that it returns data for 1 specific domain.  {{ACL: Account: Domains - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailApi;


EmailApi apiInstance = new EmailApi();
String accountId = "accountId_example"; // String | 
String domainName = "domainName_example"; // String | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse20062 result = apiInstance.getDkimDetails(accountId, domainName, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailApi#getDkimDetails");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **domainName** | **String**|  |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse20062**](InlineResponse20062.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getDkimReport"></a>
# **getDkimReport**
> InlineResponse20061 getDkimReport(accountId, cookie)



Get information about your DKIM configurations. {{ACL: Account: Domains - Manage}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailApi;


EmailApi apiInstance = new EmailApi();
String accountId = "accountId_example"; // String | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse20061 result = apiInstance.getDkimReport(accountId, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailApi#getDkimReport");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **accountId** | **String**|  |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse20061**](InlineResponse20061.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="getEmailAutoResponders"></a>
# **getEmailAutoResponders**
> InlineResponse2008 getEmailAutoResponders(username, cookie)



Return all email auto-responders owned by this user. {{ACL:User Email - Auto-Responders}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailApi;


EmailApi apiInstance = new EmailApi();
String username = "username_example"; // String | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse2008 result = apiInstance.getEmailAutoResponders(username, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailApi#getEmailAutoResponders");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse2008**](InlineResponse2008.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="newEmailAutoResponder"></a>
# **newEmailAutoResponder**
> InlineResponse2009 newEmailAutoResponder(username, body)



Create a new email auto-responer. {{ACL:User Email - Auto-Responders}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailApi;


EmailApi apiInstance = new EmailApi();
String username = "username_example"; // String | 
EmailArBody body = new EmailArBody(); // EmailArBody | 
try {
    InlineResponse2009 result = apiInstance.newEmailAutoResponder(username, body);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailApi#newEmailAutoResponder");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |
 **body** | [**EmailArBody**](EmailArBody.md)|  | [optional]

### Return type

[**InlineResponse2009**](InlineResponse2009.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="retrieveSecureLineRecipientListEncryptionData"></a>
# **retrieveSecureLineRecipientListEncryptionData**
> InlineResponse20011 retrieveSecureLineRecipientListEncryptionData(username, body, cookie)



When composing an email message, you may have a list of recipients and want to know what kind of encryption, if any, would be used for each recipient when it is finally sent out with SecureLine encryption. E.g. this can be used to (a) inform the sender of what encryption will be used, and (b) to discover ahead of time if there are some recipients for which a message cannot yet be encrypted (possible, for example, if SecureLine Escrow is setup to use question and answer authentication without a default fall-back question and answer).  It is good to use this method before sending an encrypted message – so you can modify your recipient list and/or add additional required encryption information before sending.  Note: This is a RPC-style call and hence uses a POST method even though we are “getting data”. We are interacting with the system rather than querying a specific resource. {{ACL: User Email - Sending}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailApi;


EmailApi apiInstance = new EmailApi();
String username = "username_example"; // String | 
SecurelineRecipientsBody body = new SecurelineRecipientsBody(); // SecurelineRecipientsBody | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse20011 result = apiInstance.retrieveSecureLineRecipientListEncryptionData(username, body, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailApi#retrieveSecureLineRecipientListEncryptionData");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |
 **body** | [**SecurelineRecipientsBody**](SecurelineRecipientsBody.md)|  | [optional]
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse20011**](InlineResponse20011.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

<a name="updateEmailForwarding"></a>
# **updateEmailForwarding**
> InlineResponse201 updateEmailForwarding(username, body, cookie)



This function allows you to alter the email forwarding (and denial/deletion) settings for the user. {{ACL:User Email - Forwarding}}

### Example
```java
// Import classes:
//import com.luxsci.ApiException;
//import com.luxsci.api.EmailApi;


EmailApi apiInstance = new EmailApi();
String username = "username_example"; // String | 
EmailForwardingBody body = new EmailForwardingBody(); // EmailForwardingBody | 
String cookie = null; // String (optional. can leave as null) | 
try {
    InlineResponse201 result = apiInstance.updateEmailForwarding(username, body, cookie);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling EmailApi#updateEmailForwarding");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **String**|  |
 **body** | [**EmailForwardingBody**](EmailForwardingBody.md)|  | [optional]
 **cookie** | **String**|  | [optional]

### Return type

[**InlineResponse201**](InlineResponse201.md)

### Authorization

Authorization handled with secret key and public token provided

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

